---
title: "Urubu 0.7: Python 3 support, baseurl option"
layout: page 
date: 2015-03-07
---

Urubu 0.7 adds features that make it more flexible to use. 

First, the release adds Python 3 support, from a single codebase.
You can use Python 2.7 or Python 3.4.

Second, there is now a `baseurl` option to add a prefix to generated local
URLs. [More info&nbsp;&raquo;][/manual/structure#_siteyml].

On the other hand, the checklist extension has been removed as it caused issues
with reference id resolution.


